module.exports = {
    rules: {
        // ---------------------------- 建议的风格 -----------------------------------
        // 缩进必须为4个空格
        'indent': [ 'warn', 4 , {'SwitchCase': 1}],
        // 换行符使用\n
        'linebreak-style': [ 'warn', 'unix' ],
        // 字符串只能使用单引号或者反引号
        'quotes': [ 'warn', 'single', { allowTemplateLiterals: true }],
        // 末尾需要分号
        'semi': [ 'warn', 'always' ],
        // 强制圆括号内有空格
        'space-in-parens': [ 'warn', 'never' ],
        // 强制对象的花括号中有空格
        'object-curly-spacing': [ 'warn', 'always', {
            objectsInObjects: false,
            arraysInObjects: false,
        }],
        // 强制在方括号内使用空格
        'array-bracket-spacing': [ 'warn', 'always', {
            objectsInArrays: false,
            arraysInArrays: false,
        }],
        // 要求或禁止在注释前有空白
        'spaced-comment': [ 'warn', 'always', { exceptions: [ '-', '+', '=' ]}],
        // 禁用警告注释
        'no-warning-comments': [ 'warn', {
            terms: [ 'todo', 'fixme', 'fix' ],
            location: 'anywhere',
        }],
        // 要求函数圆括号之前有一个空格，比如 function () {} 或 function aaa() {}
        'space-before-function-paren': [ 'warn', {
            anonymous: 'always',
            named: 'never',
        }],
        // 要求文件末尾保留一行空行
        'eol-last': 'warn',
        // 禁用行尾空格
        'no-trailing-spaces': [ 'warn', { skipBlankLines: true }],
        // 要求箭头函数的箭头之前或之后有空格
        'arrow-spacing': 'warn',
        // 强制模板字符串中空格的使用
        'template-curly-spacing': [ 'warn', 'always' ],
        // 要求使用拖尾逗号
        'comma-dangle': [ 'warn', 'always-multiline' ],
        // 强制在单行代码块中使用空格
        'block-spacing': 'warn',
        // 大括号风格
        'brace-style': [ 'warn', 'stroustrup', { allowSingleLine: true }],
        // 强制在逗号周围使用空格
        'comma-spacing': [ 'warn', { before: false, after: true }],
        // 强制使用一致的逗号风格
        'comma-style': [ 'warn', 'last' ],
        // 强制在对象字面量的键和值之间使用一致的空格
        'key-spacing': [ 'warn', {
            beforeColon: false,
            afterColon: true,
        }],
        // 禁止使用内联注释
        'no-inline-comments': 'off',
        // 不允许多个空行
        'no-multiple-empty-lines': [ 'warn', {
            max: 2,
            maxEOF: 1,
            maxBOF: 1,
        }],
        // parseInt 要求必须有基数
        'radix': 'off',
        // 强制文件的最大行数
        'max-lines': [ 'warn', {
            max: 1000,
            skipComments: true,
            skipBlankLines: true,
        }],
        // 强制函数内最大语句数量
        'max-statements': [ 'warn', 200 ],
        // 强制每一行中所允许的最大语句数量
        'max-statements-per-line': [ 'warn', { max: 5 }],
        // 限制最大参数个数
        'max-params': [ 'warn', 10 ],
        // 强制回调函数最大嵌套深度
        'max-nested-callbacks': [ 'warn', 10 ],
        // 要求中缀操作符周围有空格
        'space-infix-ops': [ 'warn', { int32Hint: false }],
        // 禁止 function 标识符和应用程序之间有空格
        'no-spaced-func': 'warn',
        // 禁止属性前有空白
        'no-whitespace-before-property': 'warn',
        // 禁止使用多个空格
        'no-multi-spaces': 'warn',
        // 禁止使用 空格 和 tab 混合缩进
        'no-mixed-spaces-and-tabs': 'warn',
        // 禁止对函数参数再赋值及修改其属性
        'no-param-reassign': 'warn',
        // 要求构造函数首字母大写
        'new-cap': 'error',
        // 允许_开头的未使用参数
        'no-unused-vars': [ 'warn', { argsIgnorePattern: '^_' }],
        // 禁止不必要的括号
        'no-extra-parens': 'warn',
        // disallow negating the left operand of relational operators
        'no-unsafe-negation': 'warn',
        // 建议使用 const
        'prefer-const': 'warn',
        // 禁用函数内没有yield的 generator 函数
        'require-yield': 'warn',
        // 建议 generator 函数中 * 号周围有空格，比如 function* generator() {}
        'generator-star-spacing': [ 'warn', { before: false, after: true }],
        // 建议在 yield* 表达式中 * 周围使用空格，比如 yield* other();
        'yield-star-spacing': [ 'warn', { before: false, after: true }],
        // 建议对象字面量简写语法
        // 'object-shorthand': 'warn',
        // 建议可以表达为更简单结构的条件表达式
        'no-unneeded-ternary': 'warn',
        // 禁止变量声明覆盖外层作用域的变量
        'no-shadow': [ 'off', {
            builtinGlobals: true,
            hoist: 'functions',
            allow: [ 'err', 'error', 'resolve', 'reject', 'done', 'callback', 'next', 'require', 'exports', 'module' ],
        }],
        // 变量只能在其作用域内使用
        'block-scoped-var': 'warn',
        // 禁止定义前使用变量
        'no-use-before-define': [ 'warn', {
            functions: false,
            classes: false,
        }],
        // 禁用不必要的转义, 有点问题
        'no-useless-escape': 'warn',

        // ------------------------ Pomise 强制的风格 --------------------------------
        // 调用 Pomise 函数时，必须有 .catch(callback) 或者用 return 返回当前 Promise 对象
        'promise/catch-or-return': 'error',
        // new Promise() 时，函数的参数名只能为标准的 resolve, reject
        'promise/param-names': 'error',
    }
};